.. quTARANG documentation master file, created by
   sphinx-quickstart on Sat Jan 14 15:28:12 2023.
   You can adapt this file completely to your liking, but it should at least
   contain the root `toctree` directive.

========================
Introduction to quTARANG
========================
**quTARANG** is a GPU enabled python solver for the GPE(Gross-Pitaevskii equation).  


.. note::
   This project is under active development. 
   
   
.. toctree::
   introduction
   Numerical scheme <scheme>
   Running quTARANG <usage>
   modules <modules>
   :maxdepth: 2
   :caption: Contents:



Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`
